@@ -60,7 +60,7 @@ def teardown_test_environment(teardown_funcs):
         func()
 
 
-def run_tests(test_labels, verbosity=1, interactive=True, extra_tests=[]):
+def run_tests(test_labels='', verbosity=1, interactive=True, extra_tests=[]):
     setup_funcs, teardown_funcs = get_test_enviroment_functions()
     # Prepare django for testing.
     setup_test_environment(setup_funcs)
@@ -82,8 +82,12 @@ def run_tests(test_labels, verbosity=1, interactive=True, extra_tests=[]):
     if verbosity >= 1:
         print ' '.join(nose_argv)
 
-    nose.run(argv=nose_argv)
+    success = nose.run(argv=nose_argv)
 
     # Clean up django.
     connection.creation.destroy_test_db(old_db_name, verbosity)
     teardown_test_environment(teardown_funcs)
+    if success:
+        return 0
+    else:
+        return 1
