@@ -11,9 +11,13 @@ TWILL_HOST = '127.0.0.1'
 
 TWILL_HOME = '%s:%s' % (TWILL_HOST, TWILL_PORT)
 
-def setup():
+
+def setup(*fixtures, **fixture_options):
     from django.core.servers.basehttp import AdminMediaHandler
     from django.core.handlers.wsgi import WSGIHandler
+    if fixtures:
+        from django.core.management.commands import loaddata
+        c = loaddata.Command()
+        c.handle(*fixtures, **fixture_options)
     app = AdminMediaHandler(WSGIHandler())
     add_wsgi_intercept(TWILL_HOST, TWILL_PORT, lambda: app)
-
